@@ -24,11 +24,11 @@ get '/' => sub ($c) {
     # get the known groups if there are specs
     $groups = $specs ? $specs->{group} : undef;
     $groups = [ sort @$groups ] if $groups;
-    if ($name) {
-      $settings = $synth->recall_settings(name => $name);
+    if ($group) {
+      $settings = $synth->search_settings(group => $group, name => $name);
     }
-    elsif ($group) {
-      $settings = $synth->search_settings(group => $group);
+    elsif ($name) {
+      $settings = $synth->recall_settings(name => $name);
     }
     elsif ($synth->model) {
       $settings = $synth->recall_all;
@@ -215,7 +215,7 @@ __DATA__
 %   my $my_key = $key eq 'group_to' ? 'group' : $key;
 %   my @things = $key eq 'parameter' ? ($selected->{parameter}) : $key eq 'param_to' ? ($selected->{param_to}) : $specs->{$my_key}->@*;
 %     for my $i (@things) {
-%       next if $i eq 'none';
+%       next if $i eq 'none' || $i eq '';
     <option value="<%= $i %>" <%= $i eq $selected->{$key} ? 'selected' : '' %>><%= ucfirst $i %></option>
 %     }
 %   }
@@ -223,7 +223,7 @@ __DATA__
 % }
   <p></p>
   <input type="submit" value="Submit">
-  <input type="button" value="Cancel">
+  <a href="<%= url_for('index')->query(model => $model, name => $name) %>">Cancel</a>
 </form>
 
 <script>
