@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Synthesizer settings librarian
 
-our $VERSION = '0.0014';
+our $VERSION = '0.0015';
 
 use Moo;
 use strictures 2;
@@ -92,10 +92,12 @@ sub recall_setting {
   croak 'No id given' unless $id;
   my $result = $self->_sqlite->select(
     $self->model,
-    ['settings'],
+    ['name', 'settings'],
     { id => $id },
-  )->expand(json => 'settings')->hash->{settings};
-  return $result;
+  )->expand(json => 'settings')->hash;
+  my $setting = $result->{settings};
+  $setting->{name} = $result->{name};
+  return $setting;
 }
 
 
@@ -110,6 +112,8 @@ sub recall_settings {
   my @settings;
   while (my $next = $results->hash) {
     push @settings, { $next->{id} => from_json($next->{settings}) };
+    # add the setting name to the settings data
+    $settings[-1]->{ $next->{id} }{name} = $name;
   }
   return \@settings;
 }
@@ -133,20 +137,25 @@ sub recall_all {
 
 sub search_settings {
   my ($self, %args) = @_;
+  my $name = delete $args{name};
   my @where;
+  push @where, "name = '$name'" if $name;
   for my $arg (keys %args) {
     next unless $args{$arg};
     push @where, q/json_extract(settings, '$./ . $arg . q/') = / . "'$args{$arg}'";
   }
   return [] unless @where;
-  my $sql = q/select id,settings,json_extract(settings, '$.group') as mygroup from /
+  my $sql = q/select id,name,settings,json_extract(settings, '$.group') as mygroup from /
     . $self->model
     . ' where ' . join(' and ', @where)
     . ' order by mygroup';
+  print "SQL: $sql\n" if $self->verbose;
   my $results = $self->_sqlite->query($sql);
   my @settings;
   while (my $next = $results->hash) {
     push @settings, { $next->{id} => from_json($next->{settings}) };
+    # add the setting name to the settings data
+    $settings[-1]->{ $next->{id} }{name} = $next->{name};
   }
   return \@settings;
 }
@@ -196,7 +205,7 @@ Synth::Config - Synthesizer settings librarian
 
 =head1 VERSION
 
-version 0.0014
+version 0.0015
 
 =head1 SYNOPSIS
 
